translate.storage.properties.DialectJavaUtf8

Package translate :: Package storage :: Module properties :: Class DialectJavaUtf8 |
[hide private]
[frames] | no frames]

# Class DialectJavaUtf8

source code

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods | [hide private]
encode(cls, string, encoding=None) Encode the string | source code
Inherited from `Dialect`: `find_delimiter`, `key_strip`, `value_strip`

Class Variables | [hide private]
| name = `"java-utf8"` hash(x)
| default_encoding = `"utf-8"`
| delimiters = `[u"=", u":", u" "]` hash(x)
Inherited from `Dialect`: `drop_comments`, `key_wrap_char`, `pair_terminator`, `value_wrap_char`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### encode(cls, string, encoding=None) Class Method | source code
Encode the string Overrides: Dialect.encode (inherited documentation)